public inbox for iwd@lists.linux.dev
 help / color / mirror / Atom feed
From: James Prestwood <prestwoj@gmail.com>
To: iwd@lists.linux.dev
Cc: James Prestwood <prestwoj@gmail.com>
Subject: [PATCH 1/4] station: rename ap_directed_roam to force_roam
Date: Mon, 30 Oct 2023 06:48:34 -0700	[thread overview]
Message-ID: <20231030134837.452957-2-prestwoj@gmail.com> (raw)
In-Reply-To: <20231030134837.452957-1-prestwoj@gmail.com>

This will be used for other situations where a roam is forced rather
than based on ranking.
---
 src/station.c | 16 ++++++++--------
 1 file changed, 8 insertions(+), 8 deletions(-)

diff --git a/src/station.c b/src/station.c
index 1a886b19..a2358d95 100644
--- a/src/station.c
+++ b/src/station.c
@@ -126,7 +126,7 @@ struct station {
 	bool preparing_roam : 1;
 	bool roam_scan_full : 1;
 	bool signal_low : 1;
-	bool ap_directed_roaming : 1;
+	bool force_roam : 1;
 	bool scanning : 1;
 	bool autoconnect : 1;
 	bool autoconnect_can_start : 1;
@@ -2114,7 +2114,7 @@ static void station_roam_retry(struct station *station)
 	 */
 	station->preparing_roam = false;
 	station->roam_scan_full = false;
-	station->ap_directed_roaming = false;
+	station->force_roam = false;
 
 	if (station->signal_low)
 		station_roam_timeout_rearm(station, roam_retry_interval);
@@ -2145,7 +2145,7 @@ static void station_roam_failed(struct station *station)
 	 * We were told by the AP to roam, but failed.  Try ourselves or
 	 * wait for the AP to tell us to roam again
 	 */
-	if (station->ap_directed_roaming)
+	if (station->force_roam)
 		goto delayed_retry;
 
 	/*
@@ -2425,7 +2425,7 @@ static bool station_try_next_transition(struct station *station,
 			util_address_to_string(bss->addr));
 
 	/* Reset AP roam flag, at this point the roaming behaves the same */
-	station->ap_directed_roaming = false;
+	station->force_roam = false;
 
 	/* Can we use Fast Transition? */
 	if (station_can_fast_transition(hs, bss) && !no_ft)
@@ -2583,7 +2583,7 @@ static bool station_roam_scan_notify(int err, struct l_queue *bss_list,
 	 * to occur.
 	 */
 	bss = l_queue_find(bss_list, bss_match_bssid, current_bss->addr);
-	if (bss && !station->ap_directed_roaming) {
+	if (bss && !station->force_roam) {
 		cur_bss_rank = bss->rank;
 
 		if (hs->mde && bss->mde_present && l_get_le16(bss->mde) == mdid)
@@ -2961,18 +2961,18 @@ static void station_ap_directed_roam(struct station *station,
 			MAC_STR(hdr->address_3));
 
 	/*
 	 * The ap_directed_roaming flag forces IWD to roam if there are any
 	 * candidates, even if they are worse than the current BSS. This isn't
 	 * always a good idea since we may be associated to the best BSS. Where
 	 * this does matter is if the AP indicates its going down or will be
 	 * disassociating us. If either of these bits are set, set the
 	 * ap_directed_roaming flag. Otherwise still try roaming but don't
 	 * treat it any different than a normal roam.
 	 */
 	if (req_mode & (WNM_REQUEST_MODE_DISASSOCIATION_IMMINENT |
 			WNM_REQUEST_MODE_TERMINATION_IMMINENT |
 			WNM_REQUEST_MODE_ESS_DISASSOCIATION_IMMINENT))
-		station->ap_directed_roaming = true;
+		station->force_roam = true;
 
 	if (req_mode & WNM_REQUEST_MODE_TERMINATION_IMMINENT) {
 		if (pos + 12 > body_len)
@@ -2961,18 +2961,18 @@ static void station_ap_directed_roam(struct station *station,
 
 	/*
-	 * The ap_directed_roaming flag forces IWD to roam if there are any
+	 * The force_roam flag forces IWD to roam if there are any
 	 * candidates, even if they are worse than the current BSS. This isn't
 	 * always a good idea since we may be associated to the best BSS. Where
@@ -2961,18 +2961,18 @@ static void station_ap_directed_roam(struct station *station,
 	 * this does matter is if the AP indicates its going down or will be
 	 * disassociating us. If either of these bits are set, set the
-	 * ap_directed_roaming flag. Otherwise still try roaming but don't
+	 * force_roam flag. Otherwise still try roaming but don't
 	 * treat it any different than a normal roam.
 	 */
-- 
2.25.1


  reply	other threads:[~2023-10-30 13:48 UTC|newest]

Thread overview: 19+ messages / expand[flat|nested]  mbox.gz  Atom feed  top
2023-10-30 13:48 [PATCH 0/4] Packet/beacon loss roaming improvements James Prestwood
2023-10-30 13:48 ` James Prestwood [this message]
2023-10-30 13:48 ` [PATCH 2/4] station: start roam on beacon loss event James Prestwood
2023-10-30 13:48 ` [PATCH 3/4] netdev: handle/send " James Prestwood
2023-10-30 13:48 ` [PATCH 4/4] station: rate limit packet loss roam scans James Prestwood
2023-10-30 14:48   ` Denis Kenzior
2023-10-30 15:00 ` [PATCH 0/4] Packet/beacon loss roaming improvements Denis Kenzior
2023-10-30 15:37   ` James Prestwood
2023-10-30 17:05     ` Denis Kenzior
2023-10-30 17:37       ` James Prestwood
2023-11-01 12:07         ` James Prestwood
2023-11-02  1:39           ` Denis Kenzior
2023-11-02 11:58             ` James Prestwood
2023-11-02 14:10               ` Denis Kenzior
2023-11-02 14:33                 ` James Prestwood
2023-11-02 15:17                   ` Denis Kenzior
2023-11-02 15:41                     ` James Prestwood
2023-11-02 16:10                       ` Denis Kenzior
2023-11-02 16:13                         ` James Prestwood

Reply instructions:

You may reply publicly to this message via plain-text email
using any one of the following methods:

* Save the following mbox file, import it into your mail client,
  and reply-to-all from there: mbox

  Avoid top-posting and favor interleaved quoting:
  https://en.wikipedia.org/wiki/Posting_style#Interleaved_style

* Reply using the --to, --cc, and --in-reply-to
  switches of git-send-email(1):

  git send-email \
    --in-reply-to=20231030134837.452957-2-prestwoj@gmail.com \
    --to=prestwoj@gmail.com \
    --cc=iwd@lists.linux.dev \
    /path/to/YOUR_REPLY

  https://kernel.org/pub/software/scm/git/docs/git-send-email.html

* If your mail client supports setting the In-Reply-To header
  via mailto: links, try the mailto: link
Be sure your reply has a Subject: header at the top and a blank line before the message body.
This is a public inbox, see mirroring instructions
for how to clone and mirror all data and code used for this inbox